.. aioamqp documentation master file, created by
   sphinx-quickstart on Wed Mar 19 15:35:53 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to aioamqp's documentation
==================================

Aioamqp is a library to connect to an amqp broker. It uses asyncio under the hood


Limitations
===========

For the moment, aioamqp is tested against Rabbitmq.

Contents:

.. toctree::
   :maxdepth: 2

   introduction
   changelog
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

